# otaku0info-bot
|master|develop|
|:----:|:-----:|
|[![build status](https://gitlab.namibsun.net/namibsun/python/otaku-info-bot/badges/master/build.svg)](https://gitlab.namibsun.net/namibsun/python/otaku-info-bot/commits/master)|[![build status](https://gitlab.namibsun.net/namibsun/python/otaku-info-bot/badges/develop/build.svg)](https://gitlab.namibsun.net/namibsun/python/otaku-info-bot/commits/develop)|

![Logo](resources/logo-readme.png)

A telegram bot that sends various information about Japanese media
(manga, anime, light novels and visual novels) releases.

## Further Information

* [Changelog](CHANGELOG)
* [License (GPLv3)](LICENSE)
* [Gitlab](https://gitlab.namibsun.net/namibsun/python/otaku-info-bot)
* [Github](https://github.com/namboy94/otaku-info-bot)
* [Progstats](https://progstats.namibsun.net/projects/otaku-info-bot)
* [PyPi](https://pypi.org/project/otaku-info-bot)
